# coding: utf-8

# flake8: noqa

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.0"

# import ApiClient
from memas_sdk.api_client import ApiClient

# import Configuration
from memas_sdk.configuration import Configuration

# import exceptions
from memas_sdk.exceptions import OpenApiException
from memas_sdk.exceptions import ApiAttributeError
from memas_sdk.exceptions import ApiTypeError
from memas_sdk.exceptions import ApiValueError
from memas_sdk.exceptions import ApiKeyError
from memas_sdk.exceptions import ApiException
