# coding: utf-8

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

import unittest

import memas_sdk
from memas_sdk.model.corpus_pathname import CorpusPathname
from memas_sdk import configuration


class TestCorpusPathname(unittest.TestCase):
    """CorpusPathname unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
