# coding: utf-8

"""
    MeMaS CP APIs

    This is the Control Plane APIs for MeMaS (Memory Management Service).  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: max.yu@memas.ai
    Generated by: https://openapi-generator.tech
"""

from memas_sdk.paths.cp_create_corpus.post import CreateCorpus
from memas_sdk.paths.cp_create_user.post import CreateUser


class CpApi(
    CreateCorpus,
    CreateUser,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
