# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from memas_sdk.paths.cp_create_user import Api

from memas_sdk.paths import PathValues

path = PathValues.CP_CREATE_USER